gifmaker
========

.. image:: https://badge.fury.io/py/gifmaker.svg
    :target: https://badge.fury.io/py/gifmaker

.. image:: https://github.com/neuropoly/gifmaker/workflows/build/badge.svg
    :target: https://github.com/neuropoly/gifmaker/actions?query=workflow%3Abuild

.. image:: https://github.com/neuropoly/gifmaker/workflows/publish/badge.svg
    :target: https://github.com/neuropoly/gifmaker/actions?query=workflow%3Apublish

.. image:: https://github.com/neuropoly/gifmaker/workflows/docs/badge.svg
    :target: https://neuropoly.github.io/gifmaker/

.. image:: https://img.shields.io/github/license/mashape/apistatus.svg
    :target: https://github.com/neuropoly/gifmaker/blob/master/LICENSE

.. image:: https://raw.githubusercontent.com/neuropoly/gifmaker/master/docs/brain.gif


Convert a series of images into a gif animation, with the possibility to apply
various processing on the input image (cropping, rescaling, etc.).

For installation and usage, please see the `Documentation <https://neuropoly.github.io/gifmaker>`_.
